See @README.md for general project info.

## Additional Guidelines

- Use `just` to run project tasks e.g. formatting, testing, linting (see the `justfile`).
- Once you've made changes make sure to format, test and lint the code.
